Boring Math - Probability Distributions
=======================================

PyPI project
`boring-math-probability-distributions
<https://pypi.org/project/boring-math-probability-distributions>`_.

Package to generate and visualize probability distributions.

- continuous distributions:

  - Normal: ``boring_math.probability_distributions.normal``
  - Uniform: ``boring_math.probability_distributions.uniform``

- discrete distributions:

  - Binomial: ``boring_math.probability_distributions.binomial``

This pypi project is part of the
`boring math
<https://grscheller.github.io/boring-math>`_ projects.

Documentation
-------------

Documentation for this project is hosted on
`GitHub Pages
<https://grscheller.github.io/boring-math/probability-distributions/development/build/html/>`_.

Copyright and License
---------------------

Copyright (c) 2023-2025 Geoffrey R. Scheller. Licensed under the Apache
License, Version 2.0. See the LICENSE file for details.
